==> cxf-testutils-2.0.3.1-fuse-sources.jar: org/apache/type_test/xml/TestComplexRestriction4.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ComplexRestriction4;


/**
 * <p>Java class for testComplexRestriction4 element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testComplexRestriction4">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}ComplexRestriction4"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}ComplexRestriction4"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testComplexRestriction4")
public class TestComplexRestriction4 {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ComplexRestriction4 x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ComplexRestriction4 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public ComplexRestriction4 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public void setX(ComplexRestriction4 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public ComplexRestriction4 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public void setY(ComplexRestriction4 value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestComplexRestriction4.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ComplexRestriction4;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}ComplexRestriction4"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}ComplexRestriction4"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testComplexRestriction4")
public class TestComplexRestriction4 {

    @XmlElement(required = true)
    protected ComplexRestriction4 x;
    @XmlElement(required = true)
    protected ComplexRestriction4 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public ComplexRestriction4 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public void setX(ComplexRestriction4 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public ComplexRestriction4 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction4 }
     *     
     */
    public void setY(ComplexRestriction4 value) {
        this.y = value;
    }

}
